@@ -1,6 +1,11 @@
 pub mod codspeed;
+
+#[cfg(unix)]
+pub mod fifo;
+
 mod macros;
 mod measurement;
 mod request;
+mod shared;
 pub mod utils;
-pub mod walltime;
+pub mod walltime_results;
